@@ -22,7 +22,7 @@ for template in $(find -name '*.tpl'); do
 done
 
 for class in $(find -name 'class_*.inc'); do
-  echo -en "\rConverting .tpl files: $(basename $template)                 \r"
+  echo -en "\rConverting class_*.inc files: $(basename $template)                 \r"
   sed -e 's/\($pl[DH][^=]*\)= *"\([^"]*\)";$/\1= _("\2");/g' $class > $class.new
   mv $class.new $class
 done
@@ -84,7 +84,7 @@ if [ $error -eq 0 ]; then
   read -p "Do you want to erase the message.po.orig files? (y/n)" -n1 ans
 
   if [ "$ans" == "y" -o "$ans" == "Y" ]; then
-    find $ORIG -type f -name 'messages.po.orig' -exec rm -f {} \;
+    find $ORIG/ -type f -name 'messages.po.orig' -exec rm -f {} \;
   fi
 
 else
@@ -96,9 +96,9 @@ cat << EOF
 
 ---------------------------------------------------------------------
 
-Now edit all files that have been replaced above (i.e. using kbabel)
-and mail the changes to gosa@oss.gonicus.de to be included in the
-next release.
+Now edit all files that have been replaced above (i.e. using kbabel
+or gtranslator) and mail the changes to gosa@oss.gonicus.de to be 
+included in the next release.
 
 To see the changes you've made in GOsa, run "msgfmt messages.po" on
 your freshly edited files and restart your apache after that. Set
